@@ -100,47 +100,16 @@ def _virial(T):
         warnings.warn("Cwww out of validity range")
 
     T_ = T/100
-    tau = IAPWS95.Tc/T
 
-    # Table 1
-    # Reorganizated to easy use in equations
-    tb = [-0.5, 0.875, 1, 4, 6, 12, 7]
-    nb = [0.12533547935523e-1, 0.78957634722828e1, -0.87803203303561e1,
-          -0.66856572307965, 0.20433810950965, -0.66212605039687e-4,
-          -0.10793600908932]
-    bc = [0.5, 0.75, 1, 5, 1, 9, 10]
-    nc = [0.31802509345418, -0.26145533859358, -0.19232721156002,
-          -0.25709043003438, 0.17611491008752e-1, 0.22132295167546,
-          -0.40247669763528]
-    bc2 = [4, 6, 12]
-    nc2 = [-0.66856572307965, 0.20433810950965, -0.66212605039687e-4]
-
-    # Table 2
-    ai = [3.5, 3.5]
-    bi = [0.85, 0.95]
-    Bi = [0.2, 0.2]
-    ni = [-0.14874640856724, 0.31806110878444]
-    Ci = [28, 32]
-    Di = [700, 800]
-    Ai = [0.32, 0.32]
-    betai = [0.3, 0.3]
-
-    # Eq 5
-    sum1 = sum([n*tau**t for n, t in zip(nb, tb)])
-    sum2 = 0
-    for n, b, B, A, C, D in zip(ni, bi, Bi, Ai, Ci, Di):
-        sum2 += n*((A+1-tau)**2+B)**b*exp(-C-D*(tau-1)**2)
-    Bww = Mw/IAPWS95.rhoc*(sum1+sum2)
-
-    # Eq 6
-    sum1 = sum([n*tau**t for n, t in zip(nc, bc)])
-    sum2 = sum([n*tau**t for n, t in zip(nc2, bc2)])
-    sum3 = 0
-    for a, b, B, n, C, D, A, beta in zip(ai, bi, Bi, ni, Ci, Di, Ai, betai):
-        Tita = A+1-tau
-        sum3 += n*(C*(Tita**2+B)-b*(A*Tita/beta+B*a))*(Tita**2+B)**(b-1) * \
-            exp(-C-D*(tau-1)**2)
-    Cwww = 2*(Mw/IAPWS95.rhoc)**2*(sum1-sum2+2*sum3)
+    # Virial coefficient for water
+    # The paper use the specific formulation of virial, here using the general
+    # formulation from helmholtz mEoS
+    wt = IAPWS95()
+    vir = wt._virial(T)
+    Bww = vir["B"]/wt.rhoc*wt.M
+    Cwww = vir["C"]/wt.rhoc**2*wt.M**2
+    dBwwt = -vir["Bt"]*wt.Tc/wt.rhoc*wt.M/T**2
+    dCwwwt = -vir["Ct"]*wt.Tc/wt.rhoc**2*wt.M**2/T**2
 
     # Table 3
     ai = [0.482737e-3, 0.105678e-2, -0.656394e-2, 0.294442e-1, -0.319317e-1]
@@ -171,30 +140,32 @@ def _virial(T):
         sum([i*b*T_**(-i-1) for i, b in enumerate(bi)])**2) *
         exp(sum([b/T_**i for i, b in enumerate(bi)])))
 
-    # Table 4
-    # Reorganizated to easy use in equations
-    ji = [0, 0.33, 1.01, 1.6, 3.6, 3.5]
-    ni = [0.118160747229, 0.713116392079, -0.161824192067e1, -0.101365037912,
-          -0.146629609713, 0.148287891978e-1]
-    tau = 132.6312/T
-
-    Baa = 1/10.4477*sum([n*tau**j for j, n in zip(ji, ni)])          # Eq 10
-    Caaa = 2/10.4477**2*(0.714140178971e-1+0.101365037912*tau**1.6)  # Eq 11
+    # Virial coefficient for air, using too the general virial procedure
+    air = Air()
+    vir = air._virial(T)
+    Baa = vir["B"]/air.rhoc*air.M
+    Caaa = vir["C"]/air.rhoc**2*air.M**2
+    dBaat = -vir["Bt"]*air.Tc/air.rhoc*air.M/T**2
+    dCaaat = -vir["Ct"]*air.Tc/air.rhoc**2*air.M**2/T**2
 
     prop = {}
-    prop["Baa"] = Baa/1000
+    prop["Baa"] = Baa/1e3
     prop["Baw"] = Baw
-    prop["Bww"] = Bww/1000
+    prop["Bww"] = Bww/1e3
     prop["Caaa"] = Caaa/1e6
     prop["Caaw"] = Caaw
     prop["Caww"] = Caww
     prop["Cwww"] = Cwww/1e6
-    prop["Bawt"] = Bawt
-    prop["Bawtt"] = Bawtt
-    prop["Caawt"] = Caawt
-    prop["Caawtt"] = Caawtt
-    prop["Cawwt"] = Cawwt
-    prop["Cawwtt"] = Cawwtt
+    prop["dBawt"] = Bawt
+    prop["dBawtt"] = Bawtt
+    prop["dCaawt"] = Caawt
+    prop["dCaawtt"] = Caawtt
+    prop["dCawwt"] = Cawwt
+    prop["dCawwtt"] = Cawwtt
+    prop["dBaat"] = dBaat/1e3
+    prop["dBwwt"] = dBwwt/1e3
+    prop["dCaaat"] = dCaaat/1e6
+    prop["dCwwwt"] = dCwwwt/1e6
     return prop
 
 
@@ -308,7 +279,7 @@ class Air(MEoSBlend):
     synonym = "R-729"
     rhoc = 10.4477*Ma
     Tc = 132.6306
-    Pc = 3786.0  # kPa
+    Pc = 3.7860  # MPa
     M = Ma
     Tt = 59.75
     Tb = 78.903
@@ -513,13 +484,13 @@ class Air(MEoSBlend):
             k = 1.380658e-23  # J/K
 
             # Eq 11
-            X = self.Pc*1e-3*rho/rhoc**2*fase.drhodP_T
+            X = self.Pc*rho/rhoc**2*fase.drhodP_T
 
             ref = Air()
             st = ref._Helmholtz(rho, Tref)
             drho = 1e3/self.R/Tref/(1+2*delta*st["fird"]+delta**2*st["firdd"])
 
-            Xref = self.Pc*1e-3*rho/rhoc**2*drho
+            Xref = self.Pc*rho/rhoc**2*drho
 
             # Eq 10
             bracket = X-Xref*Tref/T
@@ -963,14 +934,14 @@ class HumidAir(object):
         Mw = IAPWS95.M/1000
         vir = _virial(T)
         Baw = vir["Baw"]
-        Bawt = vir["Bawt"]
-        Bawtt = vir["Bawtt"]
+        Bawt = vir["dBawt"]
+        Bawtt = vir["dBawtt"]
         Caaw = vir["Caaw"]
-        Caawt = vir["Caawt"]
-        Caawtt = vir["Caawtt"]
+        Caawt = vir["dCaawt"]
+        Caawtt = vir["dCaawtt"]
         Caww = vir["Caww"]
-        Cawwt = vir["Cawwt"]
-        Cawwtt = vir["Cawwtt"]
+        Cawwt = vir["dCawwt"]
+        Cawwtt = vir["dCawwtt"]
 
         # Eq T45
         f = 2*A*(1-A)*rho*R*T/Ma/Mw*(Baw+3*rho/4*(A/Ma*Caaw+(1-A)/Mw*Caww))
